#!/bin/sh

# Build Script written for 'zsnes'
# Zsnes home page: http://www.zsnes.com/
# Source URL: http://sourceforge.net/project/downloading.php?groupname=zsnes&filename=zsnes151src.tar.bz2
# Build Dependencies: zenwalk-4.6,nasm-0.98.39,requiredbuilder-0.16
# Created By: raphael
# Maintainer E-Mail: rts417@yahoo.com
# Date of Build-Script Completion: Monday, August 6, 2007



# Package Variables.

name='zsnes'
version='1.5.1'
build='48.1'



# Architecture Variables.

arch='i486'
tune='i686'



# Local Variables.

buildDir=$(pwd)
srcPkg=$buildDir/zsnes151src.tar.bz2
srcDir=$buildDir/zsnes_1_51
package="$name-$version-$arch-$build"
dest="$buildDir/$package"



# Clean The Work Area, Prepare New Build Area

cd $buildDir
rm -rf $dest
rm -rf $package.tgz
rm -rf $package.md5
rm -rf $package.dep
rm -rf $srcDir
tar -xvf $srcPkg
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$name-$version
mkdir -p $dest/usr/doc/$name-$version
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/applications



# Set Ownership, Permissions, And C Flags.

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;



# Set ./configure Options.

cd $srcDir/src
./configure \
	--prefix=/usr \
	--sysconfdir=/etc \
	--localstatedir=/var \
	--with-x \
	--disable-debugger \
	--disable-cpucheck \
	--enable-release \
	force_arch=$arch



# Make And Install The Files.

make DESTDIR=$dest
make install DESTDIR=$dest



# Strip Executables (Comment Out This Section For Debugging Information).

cd $dest
chown -R root:root $dest/usr/bin
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)



# Move Documentation.

cp -R $srcDir/docs/* $dest/usr/doc/$name-$version



# Compress Man Page

gzip $dest/usr/man/man?/$name.?



# Copy The Build Script To The Package.

cp $buildDir/build-$name.sh $dest/usr/src/$name-$version/build-$name.sh



# Create The Slack Description File.

cat <<EOF > $dest/install/slack-desc 
     |-----handy-ruler------------------------------------------------------|
$name: ZSNES is a Super Nintendo Emulator.
$name:
$name: A popular Super Famicon and Super Nintendo emulator supporting
$name: OpenGL output, as well as many other advanced features.
$name:
$name:
$name:
$name:
$name:
$name:
$name:
EOF



# Create Desktop Menu Entry

cat <<EOF > $dest/usr/share/applications/$name.desktop
[Desktop Entry]
Encoding=UTF-8
Name=ZSNES
Comment=Super Nintendo Emulator
Exec=zsnes
Terminal=false
Type=Application
Categories=Game;Emulator
Icon=zsnes
EOF



# Copy The Icon To The Correct Locations

cp $srcDir/src/icons/48x48x32.png $dest/usr/share/icons/hicolor/48x48/apps/zsnes.png



# Create The Package And Clean Up

cd $dest
makepkg -l y -c n ../$package.tgz
cd $buildDir
rm -rf $srcDir
rm -rf $dest



# Create The .dep File

requiredbuilder -r -z $package.tgz > $package.dep



# Generate The MD5 Checksum

md5sum $package.tgz > $package.md5